@@ -44,10 +44,12 @@ def clean_id(input):
     remove non alphanumeric characters and lowercase
     replace whitespace by _ (underscore)
     '''
-    input=input.strip()
-    input = re.sub(r'[^A-Za-z0-9\s]+', '', input)
-    input = re.sub(r"\s", "_", input)
-    input = input.lower()
+    output=input.strip()
+    output = re.sub(r'[^A-Za-z0-9\s]+', '', output)
+    output = re.sub(r"\s", "_", output)
+    output = input.lower()
+    if not output:
+        raise (f"Cleaning {input} returned useless result")
     return input
 
 def clean_name(input):
